@@ -3,10 +3,18 @@ package Bio::Grep::Backend::BackendI;
 use strict;
 use warnings;
 
+use version; our $VERSION = qv('0.9.0');
+
 use Fatal qw (open close opendir closedir);
 
-use Bio::Grep::SearchSettings;
-use Bio::Grep::Root;
+use File::Spec;
+use File::Copy;
+use File::Temp qw/ tempfile tempdir /;
+use File::Basename;
+
+use Scalar::Util qw(reftype);
+
+use Cwd 'abs_path';
 
 use Bio::AlignIO;
 use Bio::Factory::EMBOSS;
@@ -14,22 +22,19 @@ use Bio::Index::Fasta;
 use Bio::Seq;
 use Bio::SeqIO;
 
+use Bio::Grep::SearchSettings;
+use Bio::Grep::Root;
+
 use base 'Bio::Grep::Root';
 
-use File::Spec;
-use File::Copy;
-use File::Temp qw/ tempfile tempdir /;
-
-use version; our $VERSION = qv('0.8.5');
-
 use Class::MethodMaker [
-    new      => 'new2',
-    scalar   => [qw / settings _output_fh _output_fn _current_res_id _tmp_var/],
-    array    => [qw / _query_seqs _results/],
-    hash     => [qw / features _mapping/],
+    new    => 'new2',
+    scalar => [qw / settings _output_fh _output_fn _current_res_id _tmp_var/],
+    array  => [qw / _query_seqs _results/],
+    hash   => [qw / features _mapping/],
     abstract => [
         qw / search get_sequences get_databases
-        generate_database _parse_next_res/
+            generate_database _parse_next_res/
     ],
 ];
 
@@ -44,12 +49,12 @@ sub new {
     # assume back-end binary is in path
     $self->settings->execpath('');
 
-    $self->features(%{$self->_get_all_possible_features()});
+    $self->features( %{ $self->_get_all_possible_features() } );
     $self;
 }
 
 sub _get_all_possible_features {
-    my ( $self ) = @_;
+    my ($self) = @_;
     return {
         MISMATCHES         => 1,
         GUMISMATCHES       => 1,
@@ -77,19 +82,19 @@ sub _get_all_possible_features {
         REGEX              => 1,
         REVCOM_DEFAULT     => 1,
         DIRECT_AND_REV_COM => 1,
-        NATIVE_D_A_REV_COM => 1, # backend supports searching for
-                                 # direct and revcom matches or
-                                 # do we have to emulate it? 
+        NATIVE_D_A_REV_COM => 1,    # backend supports searching for
+                                    # direct and revcom matches or
+                                    # do we have to emulate it?
     };
-}   
+}
 
 sub _get_databases {
     my ( $self, $suffix ) = @_;
     my %result = ();
-    opendir my $DIR, $self->settings->datapath ;
+    opendir my $DIR, $self->settings->datapath;
     my @files = grep {/${suffix}$/} readdir $DIR;
     closedir $DIR;
-    FILE:
+FILE:
     foreach my $file (@files) {
         my $prefix = $file;
         $prefix =~ s/$suffix//;
@@ -99,6 +104,7 @@ sub _get_databases {
         next FILE if !-e $file;
         open my $FILE, '<', $file;
         my $desc = "";
+
         while ( my $line = <$FILE> ) {
             chomp $line;
             $desc .= $line;
@@ -128,16 +134,18 @@ sub _filter_result {
 }
 
 sub results {
-    my ( $self ) = @_;
+    my ($self) = @_;
+    $self->deprecated("Use 'while (my \$res = \$sbe->next_res instead'");
     my @results;
-    while (my $res = $self->next_res ) {
+    while ( my $res = $self->next_res ) {
         push @results, $res;
     }
     wantarray ? @results : \@results;
 }
 
 sub _prepare_results {
-    my ( $self ) = @_;
+    my ($self) = @_;
+
     # sorting by dG is a Bio::Grep sortmode,  not a back-end sortmode. so we
     # have to load the results in memory and sort them.
     # next_res() will then shift the next result in _results() (see
@@ -145,27 +153,32 @@ sub _prepare_results {
     if ( $self->settings->sort_isset
         && substr( $self->settings->sort, 0, 1 ) eq 'g' )
     {
-        my @results = $self->results();
+        my @results;
+        while ( my $res = $self->next_res ) {
+            push @results, $res;
+        }
         @results = $self->_sort_by_dg(@results);
         $self->_results(@results);
-    } else {
+    }
+    else {
         $self->_results_reset;
     }
 }
 
 sub next_res {
-    my ( $self ) = @_;
+    my ($self) = @_;
     if ( $self->_results_isset ) {
         my $id = $self->_current_res_id;
-        $self->_current_res_id($id+1);
+        $self->_current_res_id( $id + 1 );
         return $self->_results->[$id];
-    } else {
+    }
+    else {
         return $self->_parse_next_res();
     }
 }
 
 sub _sort_by_dg {
-    my ($self, @results) = @_;
+    my ( $self, @results ) = @_;
     foreach my $result (@results) {
         if ( !$result->dG_isset ) {
             $self->warn(
@@ -190,8 +203,7 @@ sub _get_alignment {
     my ( $self, $seq_a, $seq_b ) = @_;
     my $factory = Bio::Factory::EMBOSS->new();
     my $prog    = $factory->program('needle');
-    my $outfile =
-        $self->_cat_path_filename( $self->settings->tmppath,
+    my $outfile = $self->_cat_path_filename( $self->settings->tmppath,
         $seq_a->id . ".out" );
     my $gapopen = '5.0';
     $gapopen = '50.0' if !$self->settings->editdistance_isset;
@@ -220,55 +232,60 @@ sub _get_alignment {
 # concatenates a path and a filename platform-independently
 sub _cat_path_filename {
     my ( $self, $path, $filename ) = @_;
-    return $filename if $path eq '';
-    return File::Spec->catfile( $path, $filename );
+    if ($path eq '') {
+        return $filename;
+    }
+    else {
+        return File::Spec->catfile( $path, $filename );
+    }    
 }
 
 sub _check_search_settings {
-    my ($self, $arg_ref) = @_;
-    
-    if (defined $arg_ref) {
+    my ( $self, $arg_ref ) = @_;
+
+    if ( defined $arg_ref ) {
         $self->settings->set($arg_ref);
-    }    
+    }
     $self->settings->upstream(0)   if !defined $self->settings->upstream;
     $self->settings->downstream(0) if !defined $self->settings->downstream;
-    
-    my %all_features = %{$self->_get_all_possible_features()};
-    
+
+    my %all_features = %{ $self->_get_all_possible_features() };
+
     my @int_features = map { lc $_ } keys %all_features, 'reverse_complement',
         'no_alignments';
 
     my %skip = (
-        FILTERS           => 1,  # checked later
-        NATIVE_ALIGNMENTS => 1,  
-        NATIVE_D_A_REV_COM=> 1,  
-        PERCENT_IDENTITY  => 1,  # no user setting
-        PROTEINS          => 1,  # no user setting
-        SORT              => 1,  # checked later
-        QUERY_FILE        => 1,  # checked later 
-        QUERY             => 1,  # checked later
-        EVALUE            => 1,  # no user setting
-        REVCOM_DEFAULT    => 1,  # no user setting
-        REGEX             => 1,  # no user setting
+        FILTERS            => 1,    # checked later
+        NATIVE_ALIGNMENTS  => 1,
+        NATIVE_D_A_REV_COM => 1,
+        PERCENT_IDENTITY   => 1,    # no user setting
+        PROTEINS           => 1,    # no user setting
+        SORT               => 1,    # checked later
+        QUERY_FILE         => 1,    # checked later
+        QUERY              => 1,    # checked later
+        EVALUE             => 1,    # no user setting
+        REVCOM_DEFAULT     => 1,    # no user setting
+        REGEX              => 1,    # no user setting
     );
-    
-    INT_FEATURE:
+
+INT_FEATURE:
     for my $option (@int_features) {
-        next INT_FEATURE if defined $skip{uc($option)};
+        next INT_FEATURE if defined $skip{ uc($option) };
+        # check if values are integers and untaint them
         $self->settings->$option(
-        $self->is_integer( $self->settings->$option ) );
-        if (!defined $self->settings->$option) {
+            $self->is_integer( $self->settings->$option ) );
+        if ( !defined $self->settings->$option ) {
             my $reset = $option . '_reset';
             $self->settings->$reset;
         }
-    } 
+    }
 
     if ( $self->settings->sort_isset ) {
-        my %sort_modes      = $self->available_sort_modes();
-        if ( defined $sort_modes{$self->settings->sort} ) {
-            my ( $sort_mode ) = $self->settings->sort =~ /(\w+)/;
+        my %sort_modes = $self->available_sort_modes();
+        if ( defined $sort_modes{ $self->settings->sort } ) {
+            my ($sort_mode) = $self->settings->sort =~ /(\w+)/;
             $self->settings->sort($sort_mode);    #make taint happy
-        } 
+        }
         else {
             $self->throw(
                 -class => 'Bio::Root::BadParameter',
@@ -288,8 +305,8 @@ sub _check_search_settings {
             -class => 'Bio::Root::BadParameter',
             -text  => 'Database not found.',
             -value => $self->settings->database,
-        ) if !defined $available_dbs{$self->settings->database};
-        
+        ) if !defined $available_dbs{ $self->settings->database };
+
     }
     else {
         $self->throw(
@@ -299,45 +316,49 @@ sub _check_search_settings {
     }
 
     # some warnings if user requests features that are not available
-    %skip = ( 
-        NATIVE_ALIGNMENTS => 1,
-        NATIVE_D_A_REV_COM=> 1,  
-        PERCENT_IDENTITY  => 1,
-        REVCOM_DEFAULT    => 1,
-        PROTEINS          => 1,
-        EVALUE            => 1,
-        REGEX             => 1,  # no user setting
+    %skip = (
+        NATIVE_ALIGNMENTS  => 1,
+        NATIVE_D_A_REV_COM => 1,
+        PERCENT_IDENTITY   => 1,
+        REVCOM_DEFAULT     => 1,
+        PROTEINS           => 1,
+        EVALUE             => 1,
+        REGEX              => 1,    # no user setting
     );
-    
-    FEATURE:
-    for my $feature (keys %all_features) {
+
+FEATURE:
+    for my $feature ( keys %all_features ) {
         next FEATURE if defined $skip{$feature};
         my $value_ok = 0;
-        if ($feature eq 'GUMISMATCHES') {
+        if ( $feature eq 'GUMISMATCHES' ) {
             $value_ok = 1;
         }
-        if (!defined( $self->features->{$feature} ) ) {
+        if ( !defined( $self->features->{$feature} ) ) {
             my $lc_f = lc($feature);
             my $lc_i = $lc_f . '_isset';
-            if ($self->settings->$lc_i  && 
-                $self->settings->$lc_f ne $value_ok) {
-                $self->warn($lc_f .' not available in this back-end.')
-            }    
+            if (   $self->settings->$lc_i
+                && $self->settings->$lc_f ne $value_ok )
+            {
+                $self->warn( $lc_f . ' not available in this back-end.' );
+            }
         }
     }
-    if (defined $self->settings->editdistance && defined $self->settings->mismatches &&
-    $self->settings->editdistance > 0 && $self->settings->mismatches > 0) {
+    if (   defined $self->settings->editdistance
+        && defined $self->settings->mismatches
+        && $self->settings->editdistance > 0
+        && $self->settings->mismatches > 0 )
+    {
         $self->throw(
             -class => 'Bio::Root::BadParameter',
-            -text  =>"Can't combine editdistance and mismatches.",
-            -value => $self->settings->editdistance . ' and ' .
-                      $self->settings->mismatches,                      
-           );
+            -text  => "Can't combine editdistance and mismatches.",
+            -value => $self->settings->editdistance . ' and '
+                . $self->settings->mismatches,
+        );
     }
     if ( $ENV{BIOGREPDEBUG} ) {
         warn $self->settings->to_string();
     }
-    
+
     # reset all filters
     if ( $self->settings->filters_isset ) {
         foreach my $filter ( @{ $self->settings->filters } ) {
@@ -354,87 +375,108 @@ sub _check_search_settings {
 # argument
 # changes directory! so please save the oldpath before calling this method
 sub _copy_fasta_file_and_create_nfo {
-    my ( $self, $file, $filename, $description ) = @_;
-    
+    my ( $self, $args ) = @_;
+
     # throw exception if filename looks wrong
-    $self->is_word($filename, 'Fasta filename');
-    
-    my $newfile =
-        $self->_cat_path_filename( $self->settings->datapath, $filename );
+    $self->is_word( $args->{basefilename}, 'Fasta filename' );
 
-    copy( $file, $newfile )
-        or $self->throw(
-        -class => 'Bio::Root::IOException',
-        -text  => "Can't copy $file to $newfile",
-        -value => $!
-        );
+    my $newfile = $self->_cat_path_filename( $self->settings->datapath,
+        $args->{basefilename} );
 
-    if ( defined($description) ) {
+    $args->{filename} = $newfile;
+
+    if ( defined $args->{copy} && $args->{copy} ) {
+        copy( $args->{file}, $newfile )
+            or $self->throw(
+            -class => 'Bio::Root::IOException',
+            -text  => "Can't copy " . $args->{file} . " to $newfile",
+            -value => $!
+            );
+    }
+    else {
+        my $abs_path = $self->is_path( abs_path( $args->{file} ) );
+        symlink( $abs_path, $newfile )
+            or $self->throw(
+            -class => 'Bio::Root::IOException',
+            -text  => "Can't symlink " . $abs_path . " to $newfile",
+            -value => $!
+            );
+    }
+    if ( defined( $args->{description} ) ) {
         open my $NFOFILE, '>', $newfile . '.nfo';
-        print $NFOFILE $description;
+        print $NFOFILE $args->{description};
         close $NFOFILE;
     }
+    return;
 }
 
 sub _guess_alphabet_of_file {
     my ( $self, $filename ) = @_;
-    my $in = Bio::SeqIO->new( -file => $filename, -format => 'fasta');
+    my $in = Bio::SeqIO->new( -file => $filename );
     return $in->next_seq->alphabet;
 }
 
-# prepares the query, for example calculating the reverse complement if necessary
+# prepares the query, for example calculating the reverse complement
+# if necessary
 # returns the prepared query. settings->query is unchanged!
 sub _prepare_query {
     my $self  = shift;
     my $query = $self->settings->query;
-    if (!defined $query) {
-        $self->throw( -class => 'Bio::Root::BadParameter',
-                      -text  => 'Query not defined.',
-                    );
-    }    
+    if ( !defined $query ) {
+        $self->throw(
+            -class => 'Bio::Root::BadParameter',
+            -text  => 'Query not defined.',
+        );
+    }
+
     #if (!$self->settings->reverse_complement_isset) {
     #    $self->settings->reverse_complement(0)
     #}
-    my $db_alphabet =
-    $self->get_alphabet_of_database($self->settings->database);
-    
-    if ($db_alphabet eq 'dna') {
+    my $db_alphabet
+        = $self->get_alphabet_of_database( $self->settings->database );
+
+    if ( $db_alphabet eq 'dna' ) {
         $query =~ tr/uU/tT/;
     }
     my $seq = Bio::Seq->new( -seq => $query );
-    if ($seq->alphabet ne $db_alphabet) {
-        $self->throw( -class => 'Bio::Root::BadParameter',
-                      -text  => 'Alphabet of query and database not equal',
-                      -value => 'Seq: '. $seq->alphabet . ", DB: $db_alphabet"
-                    );
+    if ( $seq->alphabet ne $db_alphabet ) {
+        $self->throw(
+            -class => 'Bio::Root::BadParameter',
+            -text  => 'Alphabet of query and database not equal',
+            -value => 'Seq: ' . $seq->alphabet . ", DB: $db_alphabet"
+        );
     }
-    if ($self->settings->reverse_complement ||
-        $self->settings->direct_and_rev_com) {
-        if ($db_alphabet eq 'dna') {
-            $query = $seq->revcom->seq if (!defined 
-                $self->features->{REVCOM_DEFAULT} ||
-                $self->settings->direct_and_rev_com); 
+    if (   $self->settings->reverse_complement
+        || $self->settings->direct_and_rev_com )
+    {
+        if ( $db_alphabet eq 'dna' ) {
+            $query = $seq->revcom->seq
+                if ( !defined $self->features->{REVCOM_DEFAULT}
+                || $self->settings->direct_and_rev_com );
         }
         else {
-            $self->warn("Setting reverse complement only available for DNA
-            databases. I will unset reverse complement");
-            $self->settings->reverse_complement(0);
-            $self->settings->direct_and_rev_com(0);
+            $self->throw(
+                -class => 'Bio::Root::BadParameter',
+                -text  => 
+                   'Reverse complement only available for DNA databases.',
+            );
         }
     }
-    elsif (defined $self->features->{REVCOM_DEFAULT} && $db_alphabet eq 'dna') {    
-            $query = $seq->revcom->seq 
-    }    
+    elsif ( defined $self->features->{REVCOM_DEFAULT}
+        && $db_alphabet eq 'dna' )
+    {
+        $query = $seq->revcom->seq;
+    }
     $self->settings->_real_query( uc($query) );
     return $self->settings->_real_query();
 }
 
 sub generate_database_out_of_fastafile {
     my ( $self, @args ) = @_;
-    $self->deprecated("generate_database_out_of_fastafile() is deprecated.\n".
-        "Use generate_database() instead.");
+    $self->deprecated( "generate_database_out_of_fastafile() is deprecated.\n"
+            . "Use generate_database() instead." );
     return $self->generate_database(@args);
-}    
+}
 
 sub available_sort_modes {
     my ($self) = @_;
@@ -446,10 +488,10 @@ sub available_sort_modes {
 
 sub _get_sequences_from_bio_index {
     my ( $self, $seqid ) = @_;
-    
-    $self->is_arrayref_of_size($seqid,1);
-    my $indexfile =
-        $self->settings->datapath . '/' . $self->settings->database . '.idx';
+
+    $self->is_arrayref_of_size( $seqid, 1 );
+    my $indexfile = $self->settings->datapath . '/'
+        . $self->settings->database . '.idx';
     my $idx = Bio::Index::Fasta->new($indexfile);
     my $string;
     my $stringio = IO::String->new($string);
@@ -464,18 +506,19 @@ sub _get_sequences_from_bio_index {
 sub get_alphabet_of_database {
     my ( $self, $db ) = @_;
     my %dbs = $self->get_databases();
-    if (!defined $dbs{$db}) {
-        $self->throw( -class => 'Bio::Root::BadParameter',
-                         -text  => 'Database not found',
-                         -value => $db,
-                       );
+    if ( !defined $dbs{$db} ) {
+        $self->throw(
+            -class => 'Bio::Root::BadParameter',
+            -text  => 'Database not found',
+            -value => $db,
+        );
     }
     $db = $self->is_word($db);
-    
-    open my $ALFILE, '<', $self->_cat_path_filename($self->settings->datapath,
-    $db . '.al1');
+
+    open my $ALFILE, '<',
+        $self->_cat_path_filename( $self->settings->datapath, $db . '.al1' );
     my $lines = 0;
-    while (my $line = <$ALFILE>) {
+    while ( my $line = <$ALFILE> ) {
         $lines++;
     }
     close $ALFILE;
@@ -483,28 +526,27 @@ sub get_alphabet_of_database {
 }
 
 sub _delete_output {
-    my ( $self ) = @_;
+    my ($self) = @_;
     return 0 if !defined $self->_output_fn;
     return 0 if !-e $self->_output_fn;
-    unlink $self->_output_fn or
-        $self->throw(
-            -class => 'Bio::Root::IOException',
-            -text  =>
-                "Cannot remove " . $self->_output_fn,
-            -value => $!,    
-            );
-   return 1;
+    unlink $self->_output_fn
+        or $self->throw(
+        -class => 'Bio::Root::IOException',
+        -text  => "Cannot remove " . $self->_output_fn,
+        -value => $!,
+        );
+    return 1;
 }
 
 sub _execute_command {
     my ( $self, $cmd ) = @_;
     $self->_delete_output();
-    my ( $tmp_fh, $tmp_fn ) =
-            tempfile( 'parser_XXXXXXXXXXXX', DIR => $self->settings->tmppath );
-    $self->_output_fh($tmp_fh);        
-    $self->_output_fn($tmp_fn);        
+    my ( $tmp_fh, $tmp_fn )
+        = tempfile( 'parser_XXXXXXXXXXXX', DIR => $self->settings->tmppath );
+    $self->_output_fh($tmp_fh);
+    $self->_output_fn($tmp_fn);
     system("$cmd > $tmp_fn");
-    
+
     return !$?;
 }
 
@@ -512,23 +554,25 @@ sub _create_index_and_alphabet_file {
     my ( $self, $filename ) = @_;
     my $in = Bio::SeqIO->new( -file => $filename, -format => 'Fasta' );
     my $alphabet = $in->next_seq()->alphabet();
-    if (!defined $self->features->{PROTEINS} && $alphabet eq 'protein') {
+    if ( !defined $self->features->{PROTEINS} && $alphabet eq 'protein' ) {
         $self->throw(
-        -class => 'Bio::Root::BadParameter',
-        -text  => "Back-end does not support protein data",
-        -value => $alphabet,
+            -class => 'Bio::Root::BadParameter',
+            -text  => "Back-end does not support protein data",
+            -value => $alphabet,
         );
-    }    
-    # create a vmatch alphabet file 
+    }
+
+    # create a vmatch alphabet file
     open my $ALFILE, '>', "$filename.al1";
-    if ($alphabet eq 'dna') {
+    if ( $alphabet eq 'dna' ) {
         print $ALFILE "aA\ncC\ngG\ntTuU\nnsywrkvbdhmNSYWRKVBDHM\n";
     }
     else {
         print $ALFILE
-        "L\nV\nI\nF\nK\nR\nE\nD\nA\nG\nS\nT\nN\nQ\nY\nW\nP\nH\nM\nC\nXUBZ*\n";
+            "L\nV\nI\nF\nK\nR\nE\nD\nA\nG\nS\nT\nN\nQ\nY\nW\nP\nH\nM\nC\nXUBZ*\n";
     }
     close $ALFILE;
+
     # create database from directory of fasta files
     my $idx = Bio::Index::Fasta->new(
         -filename   => $filename . '.idx',
@@ -540,38 +584,39 @@ sub _create_index_and_alphabet_file {
 }
 
 sub _create_tmp_query_file {
-    my ( $self ) = @_;
-    my $s = $self->settings;
+    my ($self)     = @_;
+    my $s          = $self->settings;
     my $query_file = 0;
     my ( $tmp_fh, $tmp_query_file );
-    if (defined $s->query_file) {
-        $query_file = $self->is_path($s->query_file);
+    if ( defined $s->query_file ) {
+        $query_file = $self->is_path( $s->query_file );
     }
-    if ($s->query_isset && $s->query_file_isset) {
+    if ( $s->query_isset && $s->query_file_isset ) {
         $self->throw(
-        -class => 'Bio::Root::BadParameter',
-        -text  => "Query and query_file are set. I am confused...",
-        -value => $s->query . ' and ' . $s->query_file,
+            -class => 'Bio::Root::BadParameter',
+            -text  => "Query and query_file are set. I am confused...",
+            -value => $s->query . ' and ' . $s->query_file,
         );
-    }    
+    }
     my @query_seqs = ();
-    
+
     my $query = '';
-    if (!$query_file) {
+    if ( !$query_file ) {
         $query = $self->_prepare_query();
 
-        ( $tmp_fh, $tmp_query_file ) =
-            tempfile( 'spatter_XXXXXXXXXXXX', DIR => $s->tmppath, UNLINK =>
-                !$ENV{BIOGREPDEBUG} ); # don't delete when in debug mode, so
-                                       # we can reproduce it.
+        ( $tmp_fh, $tmp_query_file ) = tempfile(
+            'spatter_XXXXXXXXXXXX',
+            DIR    => $s->tmppath,
+            UNLINK => !$ENV{BIOGREPDEBUG}
+        );    # don't delete when in debug mode, so
+              # we can reproduce it.
 
         # construct a temporary fasta file with the query for vmatch
         my $seqobj = Bio::Seq->new(
-            -id => 'Query',
-            -seq        => $query
+            -id  => 'Query',
+            -seq => $query
         );
-        
-        
+
         my $outseqio = Bio::SeqIO->new(
             -fh     => $tmp_fh,
             -format => 'fasta'
@@ -579,25 +624,73 @@ sub _create_tmp_query_file {
         $outseqio->write_seq($seqobj);
 
         push @query_seqs, $seqobj;
-        if($s->direct_and_rev_com && !defined
-            $self->features->{NATIVE_D_A_REV_COM}) {
+        if ( $s->direct_and_rev_com
+            && !defined $self->features->{NATIVE_D_A_REV_COM} )
+        {
             my $seqobj2 = $seqobj->revcom;
             $seqobj2->display_id('QueryRC');
             $outseqio->write_seq($seqobj2);
             push @query_seqs, $seqobj2;
-        }    
+        }
 
     }
     else {
         $tmp_query_file = $query_file;
-        my $query_in = Bio::SeqIO->new(-file => $tmp_query_file);
-        while ( my $query_seq = $query_in->next_seq) {
+        my $query_in = Bio::SeqIO->new( -file => $tmp_query_file );
+        while ( my $query_seq = $query_in->next_seq ) {
             push @query_seqs, $query_seq;
         }
     }
     $self->_query_seqs(@query_seqs);
-    return ( $query, $query_file, $tmp_query_file);
-}   
+    return ( $query, $query_file, $tmp_query_file );
+}
+
+sub _prepare_generate_database {
+    my ( $self, @args ) = @_;
+    my $reftype = reftype $args[0];
+    my %args;
+    if ( !defined $reftype ) {
+        $self->deprecated(
+                  'List argument for generate_database() is deprecated. '
+                . 'Use hashref instead.' );
+        %args = (
+            format      => 'Fasta',
+            file        => $args[0],
+            description => $args[1],
+            copy        => 0,
+        );
+    }
+    elsif ( $reftype eq 'HASH' ) {
+        %args = %{ $args[0] };
+    }
+    else {
+        $self->throw(
+            -class => 'Bio::Root::BadParameter',
+            -text  => 'Invalid arguments. Hashref assumed.',
+        );
+    }
+
+    if ( !-e $args{file} ) {
+        $self->throw(
+            -class => 'Bio::Root::BadParameter',
+            -text  => 'No such file.',
+            -value => $args{file},
+        );
+    }
+    my ($filename) = fileparse( $args{file} );
+
+    $args{basefilename} = $filename;
+
+    if ( !defined $args{format} ) {
+        $args{format} = 'Fasta';
+    }
+    if ( defined $args{datapath} ) {
+        $self->settings->datapath( $args{datapath} );
+    }
+    $self->_copy_fasta_file_and_create_nfo( \%args );
+
+    return %args;
+}
 
 1;    # Magic true value required at end of module
 __END__
@@ -730,10 +823,10 @@ Returns a hash with all available databases. The keys are the filenames,
 the values are descriptions (or the filename if no description is available).
 
 Descriptions can be set in info files. For example, if you indexed file
-ATH1.cdna, Vmatch and HyPA construct a lot of ATH1.cdna.* files. Now simply
+ATH1.cdna, Vmatch constructs a lot of ATH1.cdna.* files. Now simply
 create a file ATH1.cdna.nfo and write a description in that file. The method
-generate_database() will create this file for you if you add a description as
-second argument.
+generate_database() will create this file if C<description> is specified (see
+generate_database()).
 
   my %local_dbs_description = $sbe->get_databases();
   my @local_dbs = sort keys %local_dbs_description;
@@ -741,17 +834,52 @@ second argument.
   # take first available database 
   $sbe->settings->database($local_dbs[0]);
 
+=item C<$sbe-E<gt>generate_database({ file =E<gt> $file })>
 
-=item C<$sbe-E<gt>generate_database($fastafile)>
+Creates a symlink to the specified file in the datapath directory 
+(C<$sbe-E<gt>settings-E<gt>datapath>) and generates a database. 
 
-Copies the specified Fasta file in the datapath directory 
-(C<$sbe-E<gt>settings-E<gt>datapath>) and generates a database 
-(HyPa/Vmatch: a suffix array). You can get the available databases with 
-C<$sbe-E<gt>get_databases()>. You have to do this only once. Vmatch and HyPa 
-need a lot of RAM for the construction of their enhanced
-suffix arrays.
+  $sbe->generate_database({
+            file        => 'ATH1.cdna',
+            format      => 'Fasta',
+            description => 'AGI Transcripts',
+            copy        => 1, 
+            datapath    => 'data',
+            verbose     => 1,
+    });
 
-  $sbe->generate_database('ATH1.cdna', 'AGI Transcripts');
+You have to do this only once for every file. 
+
+Optional arguments in the hash reference are:
+
+=over 2
+
+=item C<format> 
+
+The format of C<file>. Default is C<Fasta>. See the documentation of your
+back-end and C<Bio::SeqIO> for supported formats. Only C<Fasta> is thoroughly
+tested. 
+
+=item C<description> 
+
+The description of the database. Later, you can access these descriptions with
+get_databases(). Default is the filename of C<file>.
+
+=item C<copy>
+
+Instead of adding a symlink to C<file> in the I<data> directory, copy the
+file. Useful for platforms that don't support symbolic links. Default 0
+(create a symlink).
+
+=item C<datapath>
+
+C<$sbe-E<gt>settings-E<gt>datapath> is called with this value.
+
+=item C<verbose>
+
+Generate the database more verbosely. Default is 0.
+
+=back
 
 =item C<$sbe-E<gt>generate_database_out_of_fastafile($fastafile)>
 
@@ -767,7 +895,8 @@ description.
 
 =head1 INTERNAL METHODS 
 
-Only back-ends should call them directly.
+Only back-ends should call them directly. These internal methods are
+documented for authors of new back-ends.
 
 =over 
 
@@ -786,12 +915,22 @@ Prepares the query, for example calculating the reverse complement if
 necessary, returns the prepared query. C<settings-E<gt>query> is unchanged!
 
 
-=item C<_copy_fasta_file_and_create_nfo>
+=item C<_prepare_generate_database(@args)>
 
-The generate_database() implementation of your back-end class
-should use this method to copy the specified Fasta file to the data
-directory  and to generate an info file, containing the description of the
-Fasta file.
+The method generate_database() should call this internal method as first step.
+It checks if the first argument is a valid hash reference (see
+generate_database()), sets default values for undefined keys and returns this
+modifed argument hash. Creates a symlink of the specified file (or copies this
+file) in the I<data> directory. Generates a C<.nfo> file with the description
+of the database.
+
+    sub generate_database {
+        my ( $self, @args ) = @_;
+        my %args = $self->_prepare_generate_database(@args);
+
+        $self->_create_index_and_alphabet_file( $args{filename} );
+        return $args{filename};
+    }
 
 =item C<_get_alignment( $seq_query, $seq_subject )>
 
@@ -816,21 +955,20 @@ When no file is found, the description will be the filename without the suffix:
 
 =item C<_get_sequences_from_bio_index($id)>
 
-GUUGle, Hypa, RE and Agrep back-ends use L<Bio::Index> for sequence id queries 
-(implemented in this this method). Returns a L<Bio::SeqIO> object like abstract
-method get_sequences() should.
+C<GUUGle>, C<RE> and C<Agrep> back-ends use L<Bio::Index> for sequence id queries 
+(implemented in this this method). Returns a L<Bio::SeqIO> object.
 
 =item C<_create_tmp_query_file()>
 
 Examines C<query>, C<query_file> and C<reverse_complement> and generates a 
-temporary Fasta file that is passed in the system() call to the backend. If the
+temporary Fasta file that is passed in the system() call to the back-end. If the
 environment variable C<BIOGREPDEBUG> is not set, then this file will be deleted
 when the script exits.  
 
 =item C<_create_index_and_alphabet_file($fastafile)>
 
 Creates an index of the specified Fasta file with L<Bio::Index::Fasta>.
-Creates an Vmatch alphabet file.
+Creates an C<Vmatch> alphabet file.
 
 =back
 
@@ -880,6 +1018,16 @@ C<$sbe-E<gt>settings-E<gt>datapath>. C<Bio::Root::BadParameter>.
 The database name is not valid. Allowed characters are 'a-z', 'A-z','0-9', '.'
 , '-' and '_'. C<Bio::Root::BadParameter>.
 
+=item C<Invalid arguments. Hashref assumed.>
+
+The method generate_database() assumes as first argument a hash reference.
+C<Bio::Root::BadParameter>.
+
+=item C<No such file.>
+
+The file you have specified in generate_database() does not exist.
+C<Bio::Root::BadParameter>.
+
 =item C<Query and query_file are set. I am confused...>
 
 You specified a query and a query file. C<Bio::Root::BadParameter>.
@@ -888,12 +1036,19 @@ You specified a query and a query file. C<Bio::Root::BadParameter>.
 
 You forgot to define a query or a query file. C<Bio::Root::BadParameter>.
 
+=item C<Reverse complement only available for DNA databases.>
+
+Either C<reverse_complement> or C<direct_and_rev_com> is set and the specified
+database is a protein database. These two feature are only available for DNA
+databases.
+
 =item C<Sort mode not valid.>
 
 The specified sort mode ($sbe->settings->sort) is not valid.
 You can get all valid sort modes with C<$sbe-E<gt>available_sort_modes()>
-See L<Bio::Grep::Backend::Vmatch>, L<Bio::Grep::Backend::Hypa>,
-L<Bio::Grep::Backend::Agrep> for details. C<Bio::Root::BadParameter>.
+See L<Bio::Grep::Backend::Vmatch>, L<Bio::Grep::Backend::GUUGle>,
+L<Bio::Grep::Backend::RE> and L<Bio::Grep::Backend::Agrep> for details. 
+C<Bio::Root::BadParameter>.
 
 =back
 
@@ -901,9 +1056,8 @@ L<Bio::Grep::Backend::Agrep> for details. C<Bio::Root::BadParameter>.
 
 Requires B<EMBOSS> and L<Bio::Factory::EMBOSS> for the Needleman-Wunsch local 
 alignment implementation from B<EMBOSS>. The internal method 
-C<_get_alignment($seq_a, $seq_b)> can than calculate an alignment for 
-back-ends that do not generate a alignment (like L<Bio::Grep::Backend::Hypa>
-or L<Bio::Grep::Backend::Agrep>).
+C<_get_alignment($seq_a, $seq_b)> can then calculate an alignment for 
+back-ends that do not generate an alignment (like L<Bio::Grep::Backend::Agrep>).
 
 
 =head1 SEE ALSO
